@@ -30,7 +30,6 @@ from Orange.widgets.utils import itemmodels, colorpalettes
 
 from Orange.util import scale, namegen
 from Orange.widgets.utils.widgetpreview import WidgetPreview
-from Orange.widgets.utils.state_summary import format_summary_details
 from Orange.widgets.widget import OWWidget, Msg, Input, Output
 
 
@@ -129,7 +128,7 @@ def delete(command, data, ):
         condition = indices_to_mask(command.indices, len(data))
     else:
         indices = np.asarray(command.indices)
-        if indices.dtype == np.bool:
+        if indices.dtype == bool:
             condition = indices
         else:
             condition = indices_to_mask(indices, len(data))
@@ -967,9 +966,6 @@ class OWPaintData(OWWidget):
 
         self.mainArea.layout().addWidget(self.plotview)
 
-        self.info.set_input_summary(self.info.NoInput)
-        self.info.set_output_summary(self.info.NoOutput)
-
         # enable brush tool
         self.toolActions.actions()[0].setChecked(True)
         self.set_current_tool(self.TOOLS[0][2])
@@ -1008,13 +1004,11 @@ class OWPaintData(OWWidget):
                     data = None
                 elif len(data.domain.attributes) > 2:
                     self.Information.use_first_two()
-                self.info.set_input_summary(len(data), format_summary_details(data))
             self.input_data = data
             self.btResetToInput.setDisabled(data is None)
             return bool(data)
 
         if not _check_and_set_data(data):
-            self.info.set_input_summary(self.info.NoInput)
             return
 
         X = np.array([scale(vals) for vals in data.X[:, :2].T]).T
@@ -1274,7 +1268,6 @@ class OWPaintData(OWWidget):
 
         if not self.data:
             self.Outputs.data.send(None)
-            self.info.set_output_summary(self.info.NoOutput)
             return
         data = np.array(self.data)
         if self.hasAttr2:
@@ -1305,7 +1298,6 @@ class OWPaintData(OWWidget):
 
         data.name = self.table_name
         self.Outputs.data.send(data)
-        self.info.set_output_summary(len(data), format_summary_details(data))
 
     def sizeHint(self):
         sh = super().sizeHint()
